package
Version:
v2.1.0
Opens a new window with list of versions in this module.
Published: Jul 20, 2023
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Seed create 1 hero has 1 damage, 2 heroes have 2 damages,... until n (n == 10)
type Hero struct {
mocom.ObjectID `bson:",inline"`
WeaponID interface{} `bson:"weaponId"`
Name string `bson:"name"`
Damage int `bson:"damage"`
SkillIds []int `bson:"skillIds"`
Omit bool `bson:"omit,omitempty"`
}
hero
type Weapon struct {
mocom.ID `bson:",inline"`
Type int `json:"type" bson:"type"`
Damage int `json:"damage" bson:"damage"`
}
weapon
Source Files
¶
Click to show internal directories.
Click to hide internal directories.